@@ -25,6 +25,10 @@ class IPRangeTool(Tool):
             dict(dest='print_duplicates', action='store_true')),
     ]
 
+    @classmethod
+    def print_source(cls):
+        cls._print_source(__file__)
+
     def __init__(self, *args, **kw):
         super(IPRangeTool, self).__init__(*args, **kw)
         #
@@ -66,8 +70,8 @@ class IPRangeTool(Tool):
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(IPRangeTool)
+    import xnet.tools.run
+    xnet.tools.run.run(IPRangeTool)
 
 
 if __name__ == "__main__":
