@@ -37,6 +37,10 @@ class TcpStateTool(Tool):
             dict(dest='open')),
     ]
 
+    @classmethod
+    def print_source(self):
+        print open(__file__).read()
+
     def __repr__(self):
         state = ('x', 'finished')[self.finished]
         if hasattr(self, '_addr'):
@@ -132,8 +136,8 @@ Default format:
 
 
 def main():
-    import xnet.tools
-    xnet.tools.run(TcpStateTool)
+    import xnet.tools.run
+    xnet.tools.run.run(TcpStateTool)
 
 
 if __name__ == "__main__":
